Module processing

Module processing 

Markdown post-processing rules.

These rules are applied after Markdown serialization to handle platform-specific quirks that cannot be addressed at the AST level.

Enums

MarkdownProcessingRule
Markdown post-processing rules.

Functions

parse_markdown_processing_rules
Parse markdown processing rules from a string slice array.

Type Aliases

MarkdownProcessingRules
A set of markdown processing rules to apply.